==> org.apache.sling.testing.sling-mock-oak-1.0.2-sources.jar: org/apache/jackrabbit/oak/plugins/index/diffindex/DiffIndex.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.jackrabbit.oak.plugins.index.diffindex;

import org.apache.jackrabbit.oak.spi.query.Cursor;
import org.apache.jackrabbit.oak.spi.query.Cursors;
import org.apache.jackrabbit.oak.spi.query.Filter;
import org.apache.jackrabbit.oak.spi.query.QueryIndex;
import org.apache.jackrabbit.oak.spi.state.NodeState;

/**
 * QueryIndex that relies n a diff-ing mechanism to get query results
 * 
 */
public abstract class DiffIndex implements QueryIndex {

    private final DiffCollector collector;

    public DiffIndex(DiffCollector collector) {
        this.collector = collector;
    }

    @Override
    public double getCost(Filter filter, NodeState rootState) {
        return collector.getCost(filter);
    }

    @Override
    public Cursor query(Filter filter, NodeState rootState) {
        return Cursors.newPathCursor(collector.getResults(filter), filter.getQueryEngineSettings());
    }

    @Override
    public String getPlan(Filter filter, NodeState rootState) {
        // //TODO ?
        return null;
    }
}

==> org.apache.sling.testing.sling-mock-oak-4.1.0-1.86.0-sources.jar: org/apache/jackrabbit/oak/plugins/index/diffindex/DiffIndex.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.jackrabbit.oak.plugins.index.diffindex;

import org.apache.jackrabbit.oak.plugins.index.cursor.Cursors;
import org.apache.jackrabbit.oak.spi.query.Cursor;
import org.apache.jackrabbit.oak.spi.query.Filter;
import org.apache.jackrabbit.oak.spi.query.QueryIndex;
import org.apache.jackrabbit.oak.spi.state.NodeState;

/**
 * QueryIndex that relies n a diff-ing mechanism to get query results
 * 
 */
public abstract class DiffIndex implements QueryIndex {

    private final DiffCollector collector;

    public DiffIndex(DiffCollector collector) {
        this.collector = collector;
    }

    @Override
    public double getCost(Filter filter, NodeState rootState) {
        return collector.getCost(filter);
    }

    @Override
    public Cursor query(Filter filter, NodeState rootState) {
        return Cursors.newPathCursor(collector.getResults(filter), filter.getQueryLimits());
    }

    @Override
    public String getPlan(Filter filter, NodeState rootState) {
        return "diffIndex " + filter.toString();
    }
}
